@@ -2,5 +2,5 @@ var a00479 =
 [
     [ "cppu::PropertySetMixinImpl", "a01886.html", "a01886" ],
     [ "cppu::PropertySetMixinImpl::BoundListeners", "a01890.html", "a01890" ],
-    [ "cppu::PropertySetMixin< T >", "a01894.html", "a01894" ]
+    [ "cppu::PropertySetMixin&lt; T &gt;", "a01894.html", "a01894" ]
 ];
\ No newline at end of file
